@@ -1,5 +1,6 @@
 from typing import Optional, List, Dict, Union
 import os
+import json
 import time
 import ROOT
 
@@ -18,6 +19,7 @@ class RooProcessor(AbstractObject):
         self.rdf_snapshots = {}
         self.rdf = None
         self.global_variables = {}
+        self.external_variables = {}
         self.treename = None
         
         self.load_buildin_functions()
@@ -56,12 +58,19 @@ class RooProcessor(AbstractObject):
         for i, action in enumerate(self.action_list):      
             if isinstance(action, RooProcGlobalVariables):
                 self.global_variables.update(action._params)
+            elif isinstance(action, RooProcExport):
+                data = {k:v.GetValue() for k,v in self.external_variables.items()}
+                filename = action._params['filename']
+                with open(filename, 'w') as outfile:
+                    json.dump(data, outfile, indent=2)
             else:
                 self.rdf = action.execute(self.rdf, self.global_variables)
                 if isinstance(action, RooProcSave):
                     params = action.get_formatted_parameters(self.global_variables)
                     filename = params['filename']
                     self.stdout.info(f"INFO: Writing output to `{filename}`.")
+            if isinstance(action, RooProcSum):
+                self.external_variables.update(action.ext_var)
         end = time.time()
         time_taken = end - start
         self.stdout.info(f"INFO: Task finished. Total time taken: {time_taken:.3f} s.")
\ No newline at end of file
